==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/GuardDuty/UpdateDetector.pm <==

package Paws::GuardDuty::UpdateDetector;
  use Moose;
  has DetectorId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'detectorId', required => 1);
  has Enable => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'enable');
  has FindingPublishingFrequency => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'findingPublishingFrequency');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateDetector');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/detector/{detectorId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::UpdateDetectorResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::UpdateDetector - Arguments for method UpdateDetector on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateDetector on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method UpdateDetector.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateDetector.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $UpdateDetectorResponse = $guardduty->UpdateDetector(
      DetectorId                 => 'MyDetectorId',
      Enable                     => 1,                    # OPTIONAL
      FindingPublishingFrequency => 'FIFTEEN_MINUTES',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/guardduty/UpdateDetector>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DetectorId => Str

The unique ID of the detector that you want to update.



=head2 Enable => Bool

Updated boolean value for the detector that specifies whether the
detector is enabled.



=head2 FindingPublishingFrequency => Str

A enum value that specifies how frequently customer got Finding updates
published.

Valid values are: C<"FIFTEEN_MINUTES">, C<"ONE_HOUR">, C<"SIX_HOURS">


=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateDetector in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/GuardDuty/UpdateDetector.pm <==

package Paws::GuardDuty::UpdateDetector;
  use Moose;
  has DetectorId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'detectorId', required => 1);
  has Enable => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'enable');
  has FindingPublishingFrequency => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'findingPublishingFrequency');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateDetector');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/detector/{detectorId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::UpdateDetectorResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::UpdateDetector - Arguments for method UpdateDetector on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateDetector on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method UpdateDetector.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateDetector.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $UpdateDetectorResponse = $guardduty->UpdateDetector(
      DetectorId                 => 'MyDetectorId',
      Enable                     => 1,                    # OPTIONAL
      FindingPublishingFrequency => 'FIFTEEN_MINUTES',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/guardduty/UpdateDetector>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DetectorId => Str

The unique ID of the detector to update.



=head2 Enable => Bool

Specifies whether the detector is enabled or not enabled.



=head2 FindingPublishingFrequency => Str

A enum value that specifies how frequently findings are exported, such
as to CloudWatch Events.

Valid values are: C<"FIFTEEN_MINUTES">, C<"ONE_HOUR">, C<"SIX_HOURS">


=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateDetector in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
